#include "httpd.h"
#include "http_config.h"
#include "http_log.h"
#include "ap_config.h"

#include "validate.h"

static char *get_password(request_rec *r, const char *user, const char *path)
{
    configfile_t *f;
    char l[MAX_STRING_LEN];
    const char *rpw, *w;

    if (!(f = ap_pcfg_openfile(r->pool, path))) {
        ap_log_rerror(APLOG_MARK, APLOG_ERR, r,
                      "Could not open password file: %s", path);
        return NULL;
    }
    while (!(ap_cfg_getline(l, MAX_STRING_LEN, f))) {
        if ((l[0] == '#') || (!l[0]))
            continue;
        rpw = l;
        w = ap_getword(r->pool, &rpw, ':');

        if (!strcmp(user, w)) {
            ap_cfg_closefile(f);
            return ap_getword(r->pool, &rpw, ':');
        }
    }
    ap_cfg_closefile(f);
    return NULL;
}




int maf_validate_password(request_rec *r, const char *user, const char *passwd)
{
    auth_form_conf *conf = ap_get_module_config(r->per_dir_config, &auth_form_module);
    char *real_pw, *rc;

    real_pw = get_password(r, user, conf->pwfile);
    if (real_pw == NULL) {
        return AUTH_USER_NOT_FOUND;
    }

    rc = ap_validate_password(passwd, real_pw);
    if (rc != NULL) {
        return AUTH_FAILURE;
    }

    return AUTH_OK;
}

